@@ -1,4 +1,4 @@
 """The HackerLab 9000 Library."""
 
 from hal9k.meta import Meta
-from hal9k.track import Track
+from hal9k.track import Track, TrackException
